@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::CheckListViewer;
-$Config::Model::Tk::CheckListViewer::VERSION = '1.356';
+$Config::Model::Tk::CheckListViewer::VERSION = '1.359';
 use strict;
 use warnings;
 use Carp;
@@ -64,7 +64,7 @@ sub Populate {
     $cw->{value_help_widget} = $help_widget;
     $cw->set_value_help( $leaf->get_checked_list );
 
-    $cw->add_description($leaf)->pack(@fx);
+    $cw->add_description($leaf)->pack(@fbe1);
 
     $cw->add_info_button()->pack( @fxe1, -side => 'left' );
     $cw->add_editor_button($path)->pack( @fxe1, -side => 'right' );
