@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor;
-$Config::Model::Tk::LeafEditor::VERSION = '1.351';
+$Config::Model::Tk::LeafEditor::VERSION = '1.359';
 use strict;
 use warnings;
 use Carp;
@@ -121,7 +121,7 @@ sub Populate {
     $cw->add_warning( $leaf, 'edit' )->pack(@fx);
     $cw->add_info_button()->pack( @fx, qw/-anchor n/ );
     $cw->add_summary($leaf)->pack(@fx);
-    $cw->add_description($leaf)->pack(@fx);
+    $cw->add_description($leaf)->pack(@fbe1);
     my ( $help_frame, $help_widget ) = $cw->add_help( 'help on value' => '', 1 );
     $help_frame->pack(@fx);
 
@@ -241,7 +241,7 @@ sub delete {
         # trigger redraw of Tk Tree
         $cw->reset_value;
         $cw->update_warning( $cw->{leaf} );
-        $cw->parent->parent->parent->parent->reload();
+        $cw->{store_cb}->();
     }
 }
 
