@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListEditor;
-$Config::Model::Tk::ListEditor::VERSION = '1.351';
+$Config::Model::Tk::ListEditor::VERSION = '1.359';
 use strict;
 use warnings;
 use Carp;
@@ -88,7 +88,7 @@ sub Populate {
 
     $cw->ConfigModelNoteEditor( -object => $list )->pack;
     $cw->add_summary($list)->pack(@fx);
-    $cw->add_description($list)->pack(@fx);
+    $cw->add_description($list)->pack(@fbe1);
     $cw->add_warning( $list, 'edit' )->pack(@fx);
     $cw->add_info_button($cw)->pack(@fx);
 
